@@ -23,8 +23,7 @@ STATIC_DATA_INPUTS_ROOT = Path('/ihme/covid-19/static-data')
 SNAPSHOT_ROOT = Path('/ihme/covid-19/snapshot-data/')
 MODEL_INPUTS_ROOT = Path('/ihme/covid-19/model-inputs/')
 
-DEATHS_OUTPUT_ROOT = Path('/ihme/covid-19/deaths-outputs/')
-DEATHS_SPLINE_OUTPUT_ROOT = Path('/ihme/covid-19/deaths/')
+DEATHS_SPLINE_OUTPUT_ROOT = Path('/ihme/covid-19/deaths-outputs/')
 INFECTIONATOR_OUTPUTS = Path('/ihme/covid-19/seir-inputs')
 
 MASK_USE_OUTPUT_ROOT = Path('/ihme/covid-19/mask-use-outputs')
